@@ -1,11 +1,16 @@
 #ifndef _CLASS_FACTORY_HPP_
 #define _CLASS_FACTORY_HPP_
 
+#include <gtk/gtk.h>
 #include <string>
 
-class stardict_class_factory {
+class TrayBase;
+class AppSkin;
+
+class PlatformFactory {
 public:
 	static void *create_class_by_name(const std::string& name, void *param=NULL);
+	static TrayBase *create_tray_icon(GtkWidget *, bool, GtkTooltips *, const AppSkin&);
 };
 
 #endif//!_CLASS_FACTORY_HPP_
