@@ -4,7 +4,7 @@
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -30,6 +30,7 @@
 #endif
 
 #include "stardict.h"
+#include "desktop.hpp"
 #include "conf.h"
 #include "utils.h"
 #include "iskeyspressed.hpp"
@@ -70,26 +71,26 @@ void FloatWin::Create()
 	gint screen_width = gdk_screen_get_width(screen);
 	gint screen_height = gdk_screen_get_height(screen);
 	int max_window_width=
-		conf->get_int("/apps/stardict/preferences/floating_window/max_window_width");
+		conf->get_int_at("floating_window/max_window_width");
 	int max_window_height=
-		conf->get_int("/apps/stardict/preferences/floating_window/max_window_height");
+		conf->get_int_at("floating_window/max_window_height");
 	if (max_window_width < MIN_MAX_FLOATWIN_WIDTH || 
 			max_window_width > screen_width)
-		conf->set_int("/apps/stardict/preferences/floating_window/max_window_width",
+		conf->set_int_at("floating_window/max_window_width",
 									DEFAULT_MAX_FLOATWIN_WIDTH);
 	if (max_window_height < MIN_MAX_FLOATWIN_HEIGHT ||
 			max_window_height > screen_height)
-		conf->set_int("/apps/stardict/preferences/floating_window/max_window_height", DEFAULT_MAX_FLOATWIN_HEIGHT);
+		conf->set_int_at("floating_window/max_window_height", DEFAULT_MAX_FLOATWIN_HEIGHT);
 	
 	int lock_x=
-		conf->get_int("/apps/stardict/preferences/floating_window/lock_x");
+		conf->get_int_at("floating_window/lock_x");
 	int lock_y=
-		conf->get_int("/apps/stardict/preferences/floating_window/lock_y");
+		conf->get_int_at("floating_window/lock_y");
 	
 	max_window_width=
-		conf->get_int("/apps/stardict/preferences/floating_window/max_window_width");
+		conf->get_int_at("floating_window/max_window_width");
 	max_window_height=
-		conf->get_int("/apps/stardict/preferences/floating_window/max_window_height");
+		conf->get_int_at("floating_window/max_window_height");
 	if (lock_x<0)
 		lock_x=0;
 	else if (lock_x > (screen_width - max_window_width))
@@ -148,7 +149,7 @@ void FloatWin::Create()
 	gtk_tooltips_set_tip(gpAppFrame->tooltips, StopButton, _("Stop selection-scanning"),NULL);
 
 	gtk_widget_set_sensitive(gpAppFrame->oFloatWin.StopButton, 
-													 conf->get_bool("/apps/stardict/preferences/dictionary/scan_selection"));
+													 conf->get_bool_at("dictionary/scan_selection"));
 
 #ifndef CONFIG_GPE
 	button= gtk_button_new();
@@ -170,7 +171,7 @@ void FloatWin::Create()
 
 	button = gtk_button_new();
 
-	if (conf->get_bool("/apps/stardict/preferences/floating_window/lock"))
+	if (conf->get_bool_at("floating_window/lock"))
 		lock_image= gtk_image_new_from_stock(GTK_STOCK_GOTO_LAST,GTK_ICON_SIZE_MENU);
 	else
 		lock_image= gtk_image_new_from_stock(GTK_STOCK_GO_FORWARD,GTK_ICON_SIZE_MENU);
@@ -184,69 +185,195 @@ void FloatWin::Create()
 		
 	gtk_widget_show_all(frame);
 	gtk_widget_hide(button_hbox); //show all will show hbox's children,now hide hbox only.	
+
+	if (conf->get_bool_at("floating_window/use_custom_bg")) {
+		GdkColor color;
+		color.red = conf->get_int_at("floating_window/bg_red");
+		color.green = conf->get_int_at("floating_window/bg_green");
+		color.blue = conf->get_int_at("floating_window/bg_blue");
+		set_bg(&color);
+	}
 }
 
-void FloatWin::ShowText(const gchar **word, gchar **data,const gchar * sOriginWord)
+void FloatWin::set_bg(const GdkColor *color)
 {
-  QueryingWord = sOriginWord;
-  found_result = FLOAT_WIN_FOUND;
-  view->BeginUpdate();
-  view->Clear();
-  std::string mark = "<b><span size=\"x-large\">";
-  gchar *m_str = g_markup_escape_text(sOriginWord, -1);
-  mark += m_str;
-  g_free(m_str);
-  mark += "</span></b>";
-  view->AppendPangoText(mark.c_str());
+	gtk_widget_modify_bg(FloatWindow, GTK_STATE_NORMAL, color);
+	view->modify_bg(GTK_STATE_NORMAL, color);
+}
 
-  for (int i=0; i<gpAppFrame->oLibs.ndicts(); i++) {
-    if (word[i])
-      view->AppendHeader(gpAppFrame->oLibs.dict_name(i), word[i],
-												 strcmp(word[i], sOriginWord)==0);
-    
-    if (data[i])
-      view->AppendData(data[i]);
-  }
-  view->EndUpdate();
-
-  gboolean pronounced = false;
-  gboolean canRead = gpAppFrame->oReadWord.canRead(sOriginWord);
-  if (canRead) {
-	if (PronounceWord == sOriginWord)
-		pronounced = true;
-	else
-		PronounceWord = sOriginWord;
-  } else {
-	for (int i=0;i< gpAppFrame->oLibs.ndicts(); i++) {
-		if (word[i] && strcmp(word[i], sOriginWord)) {
-			if (gpAppFrame->oReadWord.canRead(word[i])) {
-				canRead = TRUE;
-				if (PronounceWord == word[i])
-					pronounced = true;
-				else
-					PronounceWord = word[i];
-			}
-			break;
+void FloatWin::ShowText(gchar ***Word, gchar ****WordData, const gchar *sOriginWord)
+{
+	QueryingWord = sOriginWord;
+	found_result = FLOAT_WIN_FOUND;
+	view->begin_update();
+	view->clear();
+	std::string mark = "<b><span size=\"x-large\">";
+	gchar *m_str = g_markup_escape_text(sOriginWord, -1);
+	mark += m_str;
+	g_free(m_str);
+	mark += "</span></b>";
+	view->append_pango_text(mark.c_str());
+	int j,k;
+	for (size_t i=0; i<gpAppFrame->scan_dictmask.size(); i++) {
+		if (Word[i]) {
+			view->AppendNewline();
+			view->SetDictIndex(gpAppFrame->scan_dictmask[i]);
+			if (gpAppFrame->scan_dictmask[i].type == InstantDictType_LOCAL)
+				view->AppendHeader(gpAppFrame->oLibs.dict_name(gpAppFrame->scan_dictmask[i].index).c_str());
+			else
+				view->AppendHeader(gpAppFrame->oStarDictPlugins->VirtualDictPlugins.dict_name(gpAppFrame->scan_dictmask[i].index));
+			j=0;
+			do {
+				if (j==0) {
+					if (strcmp(Word[i][j], sOriginWord))
+						view->AppendWord(Word[i][j]);
+				} else {
+					view->AppendNewline();
+					view->AppendWord(Word[i][j]);
+				}
+				view->AppendData(WordData[i][j][0], Word[i][j],
+						 sOriginWord);
+				k=1;
+				while (WordData[i][j][k]) {
+					view->AppendNewline();
+					view->AppendDataSeparate();
+					view->AppendData(WordData[i][j][k],
+							 Word[i][j], sOriginWord);
+					k++;
+				}
+				j++;
+			} while (Word[i][j]);
 		}
 	}
-  }
-  gtk_widget_set_sensitive(PronounceWordButton, canRead);
+	view->end_update();
+	gboolean pronounced = false;
+	readwordtype = gpAppFrame->oReadWord.canRead(sOriginWord);
+	if (readwordtype != READWORD_CANNOT) {
+		if (PronounceWord == sOriginWord)
+			pronounced = true;
+		else
+			PronounceWord = sOriginWord;
+	} else {
+		for (size_t i=0;i< gpAppFrame->scan_dictmask.size(); i++) {
+			if (Word[i] && strcmp(Word[i][0], sOriginWord)) {
+				readwordtype = gpAppFrame->oReadWord.canRead(Word[i][0]);
+				if (readwordtype != READWORD_CANNOT) {
+					if (PronounceWord == Word[i][0])
+						pronounced = true;
+					else
+						PronounceWord = Word[i][0];
+				}
+				break;
+			}
+		}
+	}
+	gtk_widget_set_sensitive(PronounceWordButton, readwordtype != READWORD_CANNOT);
 
-  Popup(true);
-  if (canRead && (!pronounced) && conf->get_bool("/apps/stardict/preferences/floating_window/pronounce_when_popup"))
-    gpAppFrame->oReadWord.read(PronounceWord.c_str());
+	Popup(true);
+	if ((readwordtype != READWORD_CANNOT) && (!pronounced) && conf->get_bool_at("floating_window/pronounce_when_popup"))
+		gpAppFrame->oReadWord.read(PronounceWord.c_str(), readwordtype);
 }
 
-void FloatWin::ShowText(gchar ***pppWord, gchar ***pppWordData, 
-												const gchar ** ppOriginWord, gint count,
-												const gchar *sOriginWord)
+void FloatWin::ShowText(const struct STARDICT::LookupResponse::DictResponse *dict_response)
+{
+	view->begin_update();
+	bool do_append;
+	if (found_result == FLOAT_WIN_FOUND) {
+		do_append = true;
+		view->goto_end();
+	} else {
+		do_append = false;
+		view->clear();
+		view->goto_begin();
+	}
+	if (dict_response->dict_result_list.empty()) {
+		found_result = FLOAT_WIN_NET_NOT_FOUND;
+		if (do_append || !conf->get_bool_at("floating_window/show_if_not_found")) {
+			view->end_update();
+			return;
+		}
+		gchar *text;
+		gchar *m_word,*m_reason;
+		m_word = g_markup_escape_text(dict_response->oword,-1);
+		m_reason = g_markup_escape_text(_("<Not Found!>"),-1);
+		text = g_strdup_printf("<b><big>%s</big></b>\n<span foreground=\"blue\">%s</span>",m_word,m_reason);
+		view->set_pango_text(text);
+		g_free(text);
+		g_free(m_word);
+		g_free(m_reason);
+	} else {
+		found_result = FLOAT_WIN_NET_FOUND;
+		if (!do_append) {
+			std::string mark = "<b><span size=\"x-large\">";
+			gchar *m_str = g_markup_escape_text(dict_response->oword, -1);
+			mark += m_str;
+			g_free(m_str);
+			mark += "</span></b>";
+			view->append_pango_text(mark.c_str());
+		}
+		InstantDictIndex dict_index;
+		dict_index.type = InstantDictType_UNKNOWN;
+		view->SetDictIndex(dict_index);
+		for (std::list<struct STARDICT::LookupResponse::DictResponse::DictResult *>::const_iterator i = dict_response->dict_result_list.begin(); i != dict_response->dict_result_list.end(); ++i) {
+			view->AppendNewline();
+			view->AppendHeader((*i)->bookname);
+			for (std::list<struct STARDICT::LookupResponse::DictResponse::DictResult::WordResult *>::iterator j = (*i)->word_result_list.begin(); j != (*i)->word_result_list.end(); ++j) {
+				if (j == (*i)->word_result_list.begin()) {
+					if (strcmp((*j)->word, dict_response->oword)) {
+						view->AppendWord((*j)->word);
+					}
+				} else {
+					view->AppendNewline();
+					view->AppendWord((*j)->word);
+				}
+				std::list<char *>::iterator k = (*j)->datalist.begin();
+				view->AppendData(*k, (*j)->word, dict_response->oword);
+				for (++k; k != (*j)->datalist.end(); ++k) {
+					view->AppendNewline();
+					view->AppendDataSeparate();
+					view->AppendData(*k, (*j)->word, dict_response->oword);
+				}
+			}
+		}
+	}
+	view->end_update();
+	gboolean pronounced = false;
+	readwordtype = gpAppFrame->oReadWord.canRead(dict_response->oword);
+	if (readwordtype != READWORD_CANNOT) {
+		if (PronounceWord == dict_response->oword)
+			pronounced = true;
+		else
+			PronounceWord = dict_response->oword;
+	} else {
+		for (std::list<struct STARDICT::LookupResponse::DictResponse::DictResult *>::const_iterator i = dict_response->dict_result_list.begin(); i != dict_response->dict_result_list.end(); ++i) {
+			std::list<struct STARDICT::LookupResponse::DictResponse::DictResult::WordResult *>::iterator j = (*i)->word_result_list.begin();
+			if (j != (*i)->word_result_list.end() && strcmp((*j)->word, dict_response->oword)) {
+				readwordtype = gpAppFrame->oReadWord.canRead((*j)->word);
+				if (readwordtype != READWORD_CANNOT) {
+					if (PronounceWord == (*j)->word)
+						pronounced = true;
+					else
+						PronounceWord = (*j)->word;
+				}
+				break;
+			}
+		}
+	}
+	gtk_widget_set_sensitive(PronounceWordButton, readwordtype != READWORD_CANNOT);
+
+	Popup(true);
+	if ((readwordtype != READWORD_CANNOT) && (!pronounced) && conf->get_bool_at("floating_window/pronounce_when_popup"))
+		gpAppFrame->oReadWord.read(PronounceWord.c_str(), readwordtype);
+}
+
+void FloatWin::ShowText(gchar ****ppppWord, gchar *****pppppWordData, const gchar ** ppOriginWord, gint count, const gchar *sOriginWord)
 {
   QueryingWord = sOriginWord;
   found_result = FLOAT_WIN_FUZZY_FOUND;
 
-  view->BeginUpdate();
-  view->Clear();
-  view->GotoBegin();
+  view->begin_update();
+  view->clear();
+  view->goto_begin();
 
   std::string mark;
   gchar *m_str;
@@ -257,14 +384,12 @@ void FloatWin::ShowText(gchar ***pppWord, gchar ***pppWordData,
   g_free(m_str);
   mark += "</span></b> ";
   mark += _("has succeeded.\n");
-  mark += _("Found ");
   if (count ==1)
-    mark+= _("1 word:\n");
+    mark+= _("Found 1 word:\n");
   else {
-    m_str=g_strdup_printf("%d",count);
+    m_str=g_strdup_printf(_("Found %d words:\n"),count);
     mark += m_str;
     g_free(m_str);
-    mark+= _(" words:\n");
   }
   
   int j;
@@ -280,35 +405,61 @@ void FloatWin::ShowText(gchar ***pppWord, gchar ***pppWordData,
   mark += m_str;
   g_free(m_str);
   mark += "</span>";
-  view->AppendPangoText(mark.c_str());
+  view->append_pango_text(mark.c_str());
 
+  int m,n;
   for (j=0; j<count; j++) {
+    if (!ppppWord[j])
+	continue;
     mark = "\n\n<b><span size=\"x-large\">";
     m_str = g_markup_escape_text(ppOriginWord[j],-1);
     mark += m_str;
     g_free(m_str);
     mark += "</span></b>";
-    view->AppendPangoText(mark.c_str());
-    for (int i=0; i<gpAppFrame->oLibs.ndicts(); i++) {
-      if (pppWord[j][i])
-				view->AppendHeader(gpAppFrame->oLibs.dict_name(i), pppWord[j][i],
-													 strcmp(ppOriginWord[j],pppWord[j][i])==0);
-      
-			if (pppWordData[j][i])
-				view->AppendData(pppWordData[j][i]);      
+    view->append_pango_text(mark.c_str());
+    for (size_t i=0; i<gpAppFrame->scan_dictmask.size(); i++) {
+	if (ppppWord[j][i]) {
+		view->AppendNewline();
+		view->SetDictIndex(gpAppFrame->scan_dictmask[i]);
+		if (gpAppFrame->scan_dictmask[i].type == InstantDictType_LOCAL)
+			view->AppendHeader(gpAppFrame->oLibs.dict_name(gpAppFrame->scan_dictmask[i].index).c_str());
+		else if (gpAppFrame->scan_dictmask[i].type == InstantDictType_VIRTUAL)
+			view->AppendHeader(gpAppFrame->oStarDictPlugins->VirtualDictPlugins.dict_name(gpAppFrame->scan_dictmask[i].index));
+		m=0;
+		do {
+			if (m==0) {
+				if (strcmp(ppppWord[j][i][m], ppOriginWord[j]))
+					view->AppendWord(ppppWord[j][i][m]);
+			} else {
+				view->AppendNewline();
+				view->AppendWord(ppppWord[j][i][m]);
+			}
+			view->AppendData(pppppWordData[j][i][m][0], ppppWord[j][i][m],
+					 sOriginWord);
+			n=1;
+			while (pppppWordData[j][i][m][n]) {
+				view->AppendNewline();
+				view->AppendDataSeparate();
+				view->AppendData(pppppWordData[j][i][m][n],
+						 ppppWord[j][i][m], sOriginWord);
+				n++;
+			}
+			m++;
+		} while (ppppWord[j][i][m]);
+	}
     }
-  }		
-  view->EndUpdate();
+  }	
+  view->end_update();
 
-  gboolean canRead = gpAppFrame->oReadWord.canRead(sOriginWord);
-  if (canRead)
+  readwordtype = gpAppFrame->oReadWord.canRead(sOriginWord);
+  if (readwordtype != READWORD_CANNOT)
     PronounceWord = sOriginWord;
-  gtk_widget_set_sensitive(PronounceWordButton, canRead);
+  gtk_widget_set_sensitive(PronounceWordButton, readwordtype != READWORD_CANNOT);
 
  
   Popup(false);
   /*bool pronounce_when_popup=
-		conf->get_bool("/apps/stardict/preferences/floating_window/pronounce_when_popup");
+		conf->get_bool_at("floating_window/pronounce_when_popup");
 
   if (canRead && pronounce_when_popup)
     gpAppFrame->oReadWord.read(PronounceWord.c_str());*/
@@ -322,7 +473,10 @@ void FloatWin::ShowNotFound(const char* sWord,const char* sReason, gboolean fuzz
 	else
 		found_result = FLOAT_WIN_NOT_FOUND;
 
-	if (!conf->get_bool("/apps/stardict/preferences/floating_window/show_if_not_found"))
+	bool enable_netdict = conf->get_bool_at("network/enable_netdict");
+	if (enable_netdict)
+		return;
+	if (!conf->get_bool_at("floating_window/show_if_not_found"))
 		return;
 
 	gchar *text;
@@ -330,28 +484,28 @@ void FloatWin::ShowNotFound(const char* sWord,const char* sReason, gboolean fuzz
 	m_word = g_markup_escape_text(sWord,-1);
 	m_reason = g_markup_escape_text(sReason,-1);
 	text = g_strdup_printf("<b><big>%s</big></b>\n<span foreground=\"blue\">%s</span>",m_word,m_reason);
-	view->SetPangoText(text);
+	view->set_pango_text(text);
+	g_free(text);
+	g_free(m_word);
+	g_free(m_reason);
 	
 	gboolean pronounced = false;
-	gboolean canRead = gpAppFrame->oReadWord.canRead(sWord);
-	if (canRead) {
+	readwordtype = gpAppFrame->oReadWord.canRead(sWord);
+	if (readwordtype != READWORD_CANNOT) {
 		if (PronounceWord == sWord)
 			pronounced = true;
 		else
 			PronounceWord = sWord;
 	}
-	gtk_widget_set_sensitive(PronounceWordButton, canRead);
+	gtk_widget_set_sensitive(PronounceWordButton, readwordtype != READWORD_CANNOT);
 
 	if (fuzzy)
 		Popup(false);
 	else
 		Popup(true);
-	g_free(text);
-	g_free(m_word);
-	g_free(m_reason);
 
-	if (canRead && (!pronounced) && conf->get_bool("/apps/stardict/preferences/floating_window/pronounce_when_popup"))
-		gpAppFrame->oReadWord.read(PronounceWord.c_str());
+	if ((readwordtype != READWORD_CANNOT) && (!pronounced) && conf->get_bool_at("floating_window/pronounce_when_popup"))
+		gpAppFrame->oReadWord.read(PronounceWord.c_str(), readwordtype);
 }
 
 void FloatWin::Popup(gboolean updatePosition)
@@ -359,33 +513,33 @@ void FloatWin::Popup(gboolean updatePosition)
   ismoving = true;
 
   GtkRequisition requisition;
-  gtk_widget_size_request(view->Widget(), &requisition);
-	int max_window_width=conf->get_int("/apps/stardict/preferences/floating_window/max_window_width");
+  gtk_widget_size_request(view->widget(), &requisition);
+	int max_window_width=conf->get_int_at("floating_window/max_window_width");
   if (requisition.width > max_window_width) {
 		// it is not really max window width setting.
-    gtk_widget_set_size_request(view->Widget(), max_window_width, -1);
-    gtk_label_set_line_wrap(GTK_LABEL(view->Widget()), true);
-    gtk_widget_size_request(view->Widget(), &requisition); //update requisition
+    gtk_widget_set_size_request(view->widget(), max_window_width, -1);
+    gtk_label_set_line_wrap(GTK_LABEL(view->widget()), true);
+    gtk_widget_size_request(view->widget(), &requisition); //update requisition
   }
   gint window_width,window_height;
   window_width = 2*(FLOATWIN_BORDER_WIDTH+2) + requisition.width; // 2 is the frame 's width.or get it by gtk function? i am lazy,hoho
 	int max_window_height=
-		conf->get_int("/apps/stardict/preferences/floating_window/max_window_height");
+		conf->get_int_at("floating_window/max_window_height");
   if (requisition.height > max_window_height) {
     static gint vscrollbar_width = 0;
     if (!vscrollbar_width) {
-      if (view->VScrollBar()) {
+      if (view->vscroll_bar()) {
 				GtkRequisition vscrollbar_requisition;
-				gtk_widget_size_request(view->VScrollBar(), &vscrollbar_requisition);
+				gtk_widget_size_request(view->vscroll_bar(), &vscrollbar_requisition);
 				vscrollbar_width = vscrollbar_requisition.width;
-				vscrollbar_width += view->ScrollSpace();
+				vscrollbar_width += view->scroll_space();
       }
     }
-    view->SetSize(requisition.width + vscrollbar_width, max_window_height);
+    view->set_size(requisition.width + vscrollbar_width, max_window_height);
     window_height = 2*(FLOATWIN_BORDER_WIDTH+2) + max_window_height;
     window_width += vscrollbar_width;
   } else {
-    view->SetSize(requisition.width, requisition.height);
+    view->set_size(requisition.width, requisition.height);
     window_height = 2*(FLOATWIN_BORDER_WIDTH+2) + requisition.height;
   }
   
@@ -397,7 +551,7 @@ void FloatWin::Popup(gboolean updatePosition)
   }	
 
 
-	if (conf->get_bool("/apps/stardict/preferences/floating_window/lock")) {
+	if (conf->get_bool_at("floating_window/lock")) {
     gtk_window_resize(GTK_WINDOW(FloatWindow),window_width,window_height);
     now_window_width = window_width;
     now_window_height = window_height;
@@ -460,6 +614,9 @@ void FloatWin::Popup(gboolean updatePosition)
 void FloatWin::Show()
 {
 	gtk_widget_show(FloatWindow);
+#ifdef _WIN32
+	gtk_window_present(GTK_WINDOW(FloatWindow));
+#endif
 	if (!timeout)
 		timeout = g_timeout_add(FLOAT_TIMEOUT,vTimeOutCallback,this);
 }
@@ -479,7 +636,7 @@ gint FloatWin::vTimeOutCallback(gpointer data)
 {
   FloatWin *oFloatWin = static_cast<FloatWin *>(data);
 	bool lock=
-		conf->get_bool("/apps/stardict/preferences/floating_window/lock");
+		conf->get_bool_at("floating_window/lock");
   if(!lock && !oFloatWin->ismoving && 
      GTK_WIDGET_VISIBLE(oFloatWin->FloatWindow)) {
     GdkScreen *screen = gtk_window_get_screen(GTK_WINDOW(oFloatWin->FloatWindow));
@@ -488,9 +645,9 @@ gint FloatWin::vTimeOutCallback(gpointer data)
     gint iCurrentX,iCurrentY;
     gdk_display_get_pointer(display, NULL, &iCurrentX, &iCurrentY, NULL);
 		bool only_scan_while_modifier_key=
-			conf->get_bool("/apps/stardict/preferences/dictionary/only_scan_while_modifier_key");
+			conf->get_bool_at("dictionary/only_scan_while_modifier_key");
 		bool hide_floatwin_when_modifier_key_released=
-			conf->get_bool("/apps/stardict/preferences/dictionary/hide_floatwin_when_modifier_key_released");
+			conf->get_bool_at("dictionary/hide_floatwin_when_modifier_key_released");
     if (only_scan_while_modifier_key && 
 				hide_floatwin_when_modifier_key_released) {
       if (iCurrentX == oFloatWin->popup_pointer_x && iCurrentY==oFloatWin->popup_pointer_y) {
@@ -654,7 +811,7 @@ gboolean FloatWin::vLeaveNotifyCallback (GtkWidget *widget, GdkEventCrossing *ev
 void FloatWin::on_menu_copy_activate(GtkWidget * widget, FloatWin *oFloatWin)
 {
 	GtkClipboard* clipboard = gtk_clipboard_get(GDK_SELECTION_CLIPBOARD);
-	gtk_clipboard_set_text(clipboard, oFloatWin->view->GetText().c_str(), -1);
+	gtk_clipboard_set_text(clipboard, oFloatWin->view->get_text().c_str(), -1);
 }
 
 void FloatWin::on_menu_save_activate(GtkWidget * widget, FloatWin *oFloatWin)
@@ -773,29 +930,25 @@ void FloatWin::on_query_click(GtkWidget *widget, FloatWin *oFloatWin)
 {
 	play_sound_on_event("buttonactive");
 
-	if (!conf->get_bool("/apps/stardict/preferences/floating_window/lock"))
+	if (!conf->get_bool_at("floating_window/lock"))
 		oFloatWin->Hide();
 	gpAppFrame->Query(oFloatWin->QueryingWord.c_str());	
-#ifdef _WIN32
-	if (!GTK_WIDGET_VISIBLE(gpAppFrame->window))
-		gpAppFrame->oDockLet.stardict_systray_maximize(gpAppFrame->window);
-#endif
-	gtk_window_present(GTK_WINDOW(gpAppFrame->window));
+	gpAppFrame->oDockLet->maximize_from_tray();
 }
 
 void FloatWin::on_save_click(GtkWidget *widget, FloatWin *oFloatWin)
 {
-	if (conf->get_bool("/apps/stardict/preferences/dictionary/only_export_word")) {
-		FILE *fp = fopen(conf->get_string("/apps/stardict/preferences/dictionary/export_file").c_str(), "a+");
+	if (conf->get_bool_at("dictionary/only_export_word")) {
+		FILE *fp = fopen(conf->get_string_at("dictionary/export_file").c_str(), "a+");
 		if(fp) {
 			fputs(oFloatWin->QueryingWord.c_str(),fp);
 			fputs("\n",fp);
 			fclose(fp);
 		}
 	} else {
-		FILE *fp = fopen(conf->get_string("/apps/stardict/preferences/dictionary/export_file").c_str(), "a+");
+		FILE *fp = fopen(conf->get_string_at("dictionary/export_file").c_str(), "a+");
 		if(fp) {
-			fputs(oFloatWin->view->GetText().c_str(),fp);
+			fputs(oFloatWin->view->get_text().c_str(),fp);
 			fputs("\n\n",fp);
 			fclose(fp);
 		}
@@ -805,13 +958,13 @@ void FloatWin::on_save_click(GtkWidget *widget, FloatWin *oFloatWin)
 
 void FloatWin::on_play_click(GtkWidget *widget, FloatWin *oFloatWin)
 {
-	gpAppFrame->oReadWord.read(oFloatWin->PronounceWord.c_str());
+	gpAppFrame->oReadWord.read(oFloatWin->PronounceWord.c_str(), oFloatWin->readwordtype);
 }
 
 void FloatWin::on_stop_click(GtkWidget *widget, FloatWin *oFloatWin)
 {
 	play_sound_on_event("buttonactive");
-	conf->set_bool("/apps/stardict/preferences/dictionary/scan_selection", false);
+	conf->set_bool_at("dictionary/scan_selection", false);
 }
 
 #ifndef CONFIG_GPE
@@ -819,7 +972,7 @@ void FloatWin::on_help_click(GtkWidget *widget, FloatWin *oFloatWin)
 {
 	play_sound_on_event("buttonactive");
 
-	if (!conf->get_bool("/apps/stardict/preferences/floating_window/lock"))
+	if (!conf->get_bool_at("floating_window/lock"))
 		oFloatWin->Hide();
 	show_help("stardict-scan-selection");
 }
@@ -834,6 +987,6 @@ void FloatWin::on_quit_click(GtkWidget *widget, FloatWin *oFloatWin)
 void FloatWin::vLockCallback(GtkWidget *widget, FloatWin *oFloatWin)
 {
 	play_sound_on_event("buttonactive");
-	conf->set_bool("/apps/stardict/preferences/floating_window/lock", 
-								 !conf->get_bool("/apps/stardict/preferences/floating_window/lock"));
+	conf->set_bool_at("floating_window/lock", 
+								 !conf->get_bool_at("floating_window/lock"));
 }
