@@ -4,6 +4,7 @@
 #include <gtk/gtk.h>
 #include <string>
 #include "articleview.h"
+#include "readword.h"
 
 const int FLOAT_TIMEOUT=300;		        // interval used by floating window.
 const int DISAPPEAR_DISTANCE=400; // it is the square of the distance.
@@ -16,7 +17,9 @@ enum FloatWinQueryResult
 	FLOAT_WIN_FOUND,
 	FLOAT_WIN_FUZZY_FOUND,
 	FLOAT_WIN_NOT_FOUND,
-	FLOAT_WIN_FUZZY_NOT_FOUND
+	FLOAT_WIN_FUZZY_NOT_FOUND,
+	FLOAT_WIN_NET_FOUND,
+	FLOAT_WIN_NET_NOT_FOUND,
 };
 
 class FloatWin {
@@ -51,6 +54,7 @@ private:
 public:
   std::string QueryingWord;
   std::string PronounceWord;
+  ReadWordType readwordtype;
   FloatWinQueryResult found_result;
   GtkWidget *FloatWindow, *lock_image, *button_hbox;
   GtkWidget *PronounceWordButton, *StopButton;
@@ -62,9 +66,11 @@ public:
   void End();
   void ShowText(gchar ***pppWord, gchar **** ppppWordData, const gchar * sOriginWord);
   void ShowText(gchar ****ppppWord, gchar ***** pppppWordData, const gchar ** ppOriginWord, gint count,const gchar * sOriginWord);
+  void ShowText(const struct STARDICT::LookupResponse::DictResponse *dict_response);
   void ShowNotFound(const char* sWord,const char* sReason, gboolean fuzzy);
   void Show();
   void Hide();
+  void set_bg(const GdkColor *color);
 };
 
 #endif
