@@ -1,10 +1,15 @@
 #ifndef __SD_LIB_H__
 #define __SD_LIB_H__
 
+#include "stardict_libconfig.h"
+
 #include "common.hpp"
 #include "data.hpp"
 #include "stddict.hpp"
+
+#ifdef SD_CLIENT_CODE
 #include "treedict.hpp"
+#endif
 
 static inline gchar* stardict_datadup(gconstpointer mem)
 {
@@ -16,5 +21,6 @@ typedef enum {
 } query_t;
 	
 extern query_t analyse_query(const char *s, std::string& res); 
+extern void stardict_input_escape(const char *text, std::string &res);
 
 #endif//!__SD_LIB_H__
