@@ -10,7 +10,6 @@
 
 class PrefsDlg {
 private:
-  GtkWidget *window;
   GtkWidget *notebook;
 #ifndef CONFIG_GPE
   GtkWidget *categories_tree;
@@ -21,19 +20,28 @@ private:
   GtkWidget *collation_hbox;
   GtkWidget *tts_textview;
   GtkWidget *searchwebsite_treeview;
-
+  GtkWidget *use_tts_program_hbox;
+ 
   GtkWindow *parent_window;
 #ifndef CONFIG_GPE
   GdkPixbuf *stardict_logo;
 #endif
   GtkEntry *eExportFile;
+  GtkEntry *eStarDictServer;
+  GtkEntry *eStarDictServerPort;
+  GtkButton *bAccount;
+  std::string register_user;
+  std::string register_hex;
 #if defined(CONFIG_GTK) || defined(CONFIG_GPE)
   GtkEntry *ePlayCommand;
 #endif
 #ifndef CONFIG_GPE
   GtkWidget *categories_window;
 #endif
-	const std::list<std::string>& key_combs;
+#ifndef _WIN32
+  GtkEntry *eTTSCommandline;
+#endif
+  const std::list<std::string>& key_combs;
 
 #ifndef CONFIG_GPE
   GtkTreeModel* create_categories_tree_model ();		
@@ -45,6 +53,8 @@ private:
   void setup_dictionary_cache_page();
   void setup_dictionary_export_page();
   void setup_dictionary_sound_page();
+  void setup_dict_article_rendering();
+  void setup_network_netdict();
   void setup_mainwin_input_page();
   void setup_mainwin_options_page();
   void setup_mainwin_searchwebsite_page();
@@ -70,16 +80,23 @@ private:
   static void on_setup_dictionary_scan_clipboard_ckbutton_toggled(GtkToggleButton *button, PrefsDlg *oPrefsDlg);
   static void on_setup_dictionary_use_scan_hotkey_ckbutton_toggled(GtkToggleButton *button, PrefsDlg *oPrefsDlg);
 #endif
-  static void on_setup_dictionary_scan_optionmenu_changed(GtkOptionMenu *option_menu, PrefsDlg *oPrefsDlg);
+  static void on_setup_dictionary_scan_combobox_changed(GtkComboBox *combobox, PrefsDlg *oPrefsDlg);
   static void on_setup_dictionary_scan_hide_ckbutton_toggled(GtkToggleButton *button, PrefsDlg *oPrefsDlg);
   static void on_setup_dictionary_cache_CreateCacheFile_ckbutton_toggled(GtkToggleButton *button, PrefsDlg *oPrefsDlg);
   static void on_setup_dictionary_cache_EnableCollation_ckbutton_toggled(GtkToggleButton *button, PrefsDlg *oPrefsDlg);
-  static void on_setup_dictionary_collation_optionmenu_changed(GtkOptionMenu *option_menu, PrefsDlg *oPrefsDlg);
+  static void on_setup_dictionary_collation_combobox_changed(GtkComboBox *combobox, PrefsDlg *oPrefsDlg);
   static void on_setup_dictionary_cache_cleanbutton_clicked(GtkWidget *widget, PrefsDlg *oPrefsDlg);
   static void on_setup_dictionary_export_ckbutton_toggled(GtkToggleButton *button, PrefsDlg *oPrefsDlg);
   static void on_setup_dictionary_export_browse_button_clicked(GtkButton *button, PrefsDlg *oPrefsDlg);
   static void on_setup_dictionary_sound_ckbutton_toggled(GtkToggleButton *button, PrefsDlg *oPrefsDlg);
+#ifndef _WIN32
+  static void on_setup_dictionary_use_tts_program_ckbutton_toggled(GtkToggleButton *button, PrefsDlg *oPrefsDlg);
+#endif
+  static void on_setup_network_netdict_ckbutton_toggled(GtkToggleButton *button, PrefsDlg *oPrefsDlg);
+  static void on_setup_network_account_button_clicked(GtkWidget *widget, PrefsDlg *oPrefsDlg);
+  static void on_setup_network_register_button_clicked(GtkWidget *widget, PrefsDlg *oPrefsDlg);
   static void on_setup_mainwin_searchWhileTyping_ckbutton_toggled(GtkToggleButton *button, PrefsDlg *oPrefsDlg);
+  static void on_setup_mainwin_input_timeout_spinbutton_changed(GtkSpinButton *button, PrefsDlg *oPrefsDlg);
   static void on_setup_mainwin_showfirstWhenNotfound_ckbutton_toggled(GtkToggleButton *button, PrefsDlg *oPrefsDlg);
   static void on_setup_mainwin_startup_ckbutton_toggled(GtkToggleButton *button, PrefsDlg *oPrefsDlg);
 #ifdef _WIN32
@@ -97,15 +114,20 @@ private:
 #ifndef CONFIG_GPE
   static void on_setup_floatwin_size_max_width_spinbutton_changed(GtkSpinButton *button, PrefsDlg *oPrefsDlg);
   static void on_setup_floatwin_size_max_height_spinbutton_changed(GtkSpinButton *button, PrefsDlg *oPrefsDlg);
+  static void on_setup_floatwin_use_custom_bg_toggled(GtkToggleButton *button, PrefsDlg *oPrefsDlg);
+  static void on_setup_floatwin_color_set(GtkColorButton *widget, PrefsDlg *oPrefsDlg);
+  static void on_markup_search_word(GtkToggleButton *, PrefsDlg *);
 
   void resize_categories_tree(void);
 #endif
 
   void change_font_for_all_widgets(const std::string& fontname);
 public:
+  GtkWidget *window;
   PrefsDlg(GtkWindow *parent, GdkPixbuf *logo, const std::list<std::string>& key_combs);
   bool ShowModal();
   void Close();
+  void on_register_end(const char *msg);
 };
 
 #endif
