@@ -1,11 +1,11 @@
 /* 
  * This file part of StarDict - A international dictionary for GNOME.
  * http://stardict.sourceforge.net
- * Copyright (C) 2005 Evgeniy <dushistov@mail.ru>
+ * Copyright (C) 2005-2006 Evgeniy <dushistov@mail.ru>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -25,6 +25,7 @@
 #include <glib.h>
 #include <glib/gi18n.h>
 #include <cstdlib>
+#include <gtk/gtk.h>
 
 #ifdef CONFIG_GNOME
 #  include <libgnome/libgnome.h>
@@ -33,56 +34,8 @@
 #  include <gdk/gdkwin32.h>
 #endif
 
-#include "conf.h"
-#include "stardict.h"
-
 #include "utils.h"
 
-#if defined(CONFIG_GTK) || defined(CONFIG_GPE)
-static void spawn_command(const gchar *exe, const gchar *arg)
-{
-  gchar *cmd=g_strdup_printf("%s '%s'", exe, arg);
-  g_spawn_command_line_async(cmd, NULL);
-  g_free(cmd);
-}
-#endif
-
-void play_wav_file(const std::string& filename)
-{
-#ifdef _WIN32
-  PlaySound(filename.c_str(), 0, SND_ASYNC | SND_FILENAME);
-#elif defined(CONFIG_GNOME)
-  gnome_sound_play(filename.c_str());
-#else
-	const std::string &playcmd=
-		conf->get_string("/apps/stardict/preferences/dictionary/play_command");
-  spawn_command(playcmd.c_str(), filename.c_str());
-#endif
-}
-
-void show_help(const gchar *section)
-{
-#ifdef _WIN32
-  gchar *filename = g_strdup_printf(_("%s\\help\\stardict.chm"), gStarDictDataDir.c_str());
-  ShellExecute((HWND)(GDK_WINDOW_HWND(gpAppFrame->window->window)), "OPEN", filename, NULL, NULL, SW_SHOWNORMAL);
-  g_free(filename);
-#elif defined(CONFIG_GNOME)
-  gnome_help_display ("stardict.xml", section, NULL);
-#endif
-}
-
-void show_url(const gchar *url)
-{
-#ifdef _WIN32
-	ShellExecute((HWND)(GDK_WINDOW_HWND(gpAppFrame->window->window)), "OPEN", url, NULL, NULL, SW_SHOWNORMAL);
-#elif defined(CONFIG_GNOME)
-	gnome_url_show(url, NULL);
-#elif defined(CONFIG_GPE)
-	gchar *command = g_strdup_printf("gpe-mini-browser %s", url);
-	system(command);
-	g_free(command);
-#endif
-}
 
 void ProcessGtkEvent()
 {
@@ -182,9 +135,3 @@ GdkPixbuf *load_image_from_file(const std::string& filename)
 
 	return res;
 }
-
-void play_sound_on_event(const gchar *eventname)
-{
-	if (conf->get_bool("/apps/stardict/preferences/dictionary/enable_sound_event"))
-	  play_wav_file(gStarDictDataDir+ G_DIR_SEPARATOR_S "sounds" G_DIR_SEPARATOR_S +eventname+".wav");
-}
